@@ -57,22 +57,21 @@ exchange_message_info_dup_to (CamelMessageInfoBase *dest,
 static gint
 exchange_entry_play_append (CamelOfflineJournal *journal,
                             CamelExchangeJournalEntry *entry,
-                            CamelException *ex)
+                            GError **error)
 {
 	CamelExchangeFolder *exchange_folder = (CamelExchangeFolder *) journal->folder;
 	CamelFolder *folder = journal->folder;
 	CamelMimeMessage *message;
 	CamelMessageInfo *info, *real;
 	CamelStream *stream;
-	CamelException lex;
 	gchar *uid = NULL;
 
 	/* if the message isn't in the cache, the user went behind our backs so "not our problem" */
-	if (!exchange_folder->cache || !(stream = camel_data_cache_get (exchange_folder->cache, "cache", entry->uid, ex)))
+	if (!exchange_folder->cache || !(stream = camel_data_cache_get (exchange_folder->cache, "cache", entry->uid, NULL)))
 		goto done;
 
 	message = camel_mime_message_new ();
-	if (camel_data_wrapper_construct_from_stream ((CamelDataWrapper *) message, stream) == -1) {
+	if (camel_data_wrapper_construct_from_stream ((CamelDataWrapper *) message, stream, NULL) == -1) {
 		g_object_unref (message);
 		g_object_unref (stream);
 		goto done;
@@ -85,13 +84,8 @@ exchange_entry_play_append (CamelOfflineJournal *journal,
 		info = camel_message_info_new (NULL);
 	}
 
-	camel_exception_init (&lex);
-	camel_folder_append_message (folder, message, info, &uid, &lex);
-
-	if (camel_exception_is_set (&lex)) {
-		camel_exception_xfer (ex, &lex);
+	if (!camel_folder_append_message (folder, message, info, &uid, error))
 		return -1;
-	}
 
 	real = camel_folder_summary_info_new_from_message (folder->summary, message, NULL);
 	g_object_unref (message);
@@ -115,24 +109,23 @@ exchange_entry_play_append (CamelOfflineJournal *journal,
 static gint
 exchange_entry_play_transfer (CamelOfflineJournal *journal,
                               CamelExchangeJournalEntry *entry,
-                              CamelException *ex)
+                              GError **error)
 {
 	CamelExchangeFolder *exchange_folder = (CamelExchangeFolder *) journal->folder;
 	CamelFolder *folder = journal->folder;
 	CamelMessageInfo *info, *real;
 	GPtrArray *xuids, *uids;
-	CamelException lex;
 	CamelFolder *src;
 	CamelExchangeStore *store;
 	CamelStream *stream;
 	CamelMimeMessage *message;
 	CamelStore *parent_store;
 
-	if (!exchange_folder->cache || !(stream = camel_data_cache_get (exchange_folder->cache, "cache", entry->uid, ex)))
+	if (!exchange_folder->cache || !(stream = camel_data_cache_get (exchange_folder->cache, "cache", entry->uid, NULL)))
 		goto done;
 
 	message = camel_mime_message_new ();
-	if (camel_data_wrapper_construct_from_stream ((CamelDataWrapper *) message, stream) == -1) {
+	if (camel_data_wrapper_construct_from_stream ((CamelDataWrapper *) message, stream, NULL) == -1) {
 		g_object_unref (message);
 		g_object_unref (stream);
 		goto done;
@@ -146,7 +139,9 @@ exchange_entry_play_transfer (CamelOfflineJournal *journal,
 	}
 
 	if (!entry->folder_name) {
-		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("No folder name found\n"));
+		g_set_error (
+			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
+			_("No folder name found"));
 		goto exception;
 	}
 
@@ -158,30 +153,36 @@ exchange_entry_play_transfer (CamelOfflineJournal *journal,
 	g_mutex_unlock (store->folders_lock);
 
 	if (src) {
+		gboolean success;
 		uids = g_ptr_array_sized_new (1);
 		g_ptr_array_add (uids, entry->original_uid);
 
-		camel_exception_init (&lex);
-		camel_folder_transfer_messages_to (src, uids, folder, &xuids, entry->delete_original, &lex);
-		if (!camel_exception_is_set (&lex)) {
-			real = camel_folder_summary_info_new_from_message (folder->summary, message, NULL);
-			g_object_unref (message);
-			real->uid = camel_pstring_strdup ((gchar *)xuids->pdata[0]);
-			/* Transfer flags */
-			exchange_message_info_dup_to ((CamelMessageInfoBase *) real, (CamelMessageInfoBase *) info);
-			camel_folder_summary_add (folder->summary, real);
-			/* FIXME: should a folder_changed event be triggered? */
-		} else {
-			camel_exception_xfer (ex, &lex);
+		success = camel_folder_transfer_messages_to (
+			src, uids, folder, &xuids,
+			entry->delete_original, error);
+		if (!success)
 			goto exception;
-		}
+
+		real = camel_folder_summary_info_new_from_message (
+			folder->summary, message, NULL);
+		g_object_unref (message);
+		real->uid = camel_pstring_strdup (
+			(gchar *)xuids->pdata[0]);
+		/* Transfer flags */
+		exchange_message_info_dup_to (
+			(CamelMessageInfoBase *) real,
+			(CamelMessageInfoBase *) info);
+		camel_folder_summary_add (folder->summary, real);
+		/* FIXME: should a folder_changed event be triggered? */
 
 		g_ptr_array_free (xuids, TRUE);
 		g_ptr_array_free (uids, TRUE);
 		/* g_object_unref (src); FIXME: should we? */
-	}
-	else {
-		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("Folder doesn't exist"));
+
+	} else {
+		g_set_error (
+			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
+			_("Folder doesn't exist"));
 		goto exception;
 	}
 
@@ -201,21 +202,22 @@ exception:
 static gint
 exchange_entry_play_delete (CamelOfflineJournal *journal,
                             CamelExchangeJournalEntry *entry,
-                            CamelException *ex)
+                            GError **error)
 {
 	CamelFolder *folder;
 	CamelStore *parent_store;
 	const gchar *full_name;
+	gboolean success;
 
 	folder = CAMEL_FOLDER (journal->folder);
 	full_name = camel_folder_get_full_name (folder);
 	parent_store = camel_folder_get_parent_store (folder);
 
-	camel_exchange_utils_set_message_flags (
+	success = camel_exchange_utils_set_message_flags (
 		CAMEL_SERVICE (parent_store), full_name,
-		entry->uid, entry->set, entry->flags, ex);
+		entry->uid, entry->set, entry->flags, error);
 
-	return 0;
+	return success ? 0 : -1;
 }
 
 static void
@@ -344,17 +346,20 @@ exchange_journal_entry_write (CamelOfflineJournal *journal,
 static gint
 exchange_journal_entry_play (CamelOfflineJournal *journal,
                              CamelDListNode *entry,
-                             CamelException *ex)
+                             GError **error)
 {
 	CamelExchangeJournalEntry *exchange_entry = (CamelExchangeJournalEntry *) entry;
 
 	switch (exchange_entry->type) {
 	case CAMEL_EXCHANGE_JOURNAL_ENTRY_APPEND:
-		return exchange_entry_play_append (journal, exchange_entry, ex);
+		return exchange_entry_play_append (
+			journal, exchange_entry, error);
 	case CAMEL_EXCHANGE_JOURNAL_ENTRY_TRANSFER:
-		return exchange_entry_play_transfer (journal, exchange_entry, ex);
+		return exchange_entry_play_transfer (
+			journal, exchange_entry, error);
 	case CAMEL_EXCHANGE_JOURNAL_ENTRY_DELETE:
-		return exchange_entry_play_delete (journal, exchange_entry, ex);
+		return exchange_entry_play_delete (
+			journal, exchange_entry, error);
 	default:
 		g_critical ("%s: Uncaught case (%d)", G_STRLOC, exchange_entry->type);
 		return -1;
@@ -392,8 +397,11 @@ camel_exchange_journal_new (CamelExchangeFolder *folder, const gchar *filename)
 }
 
 static gboolean
-update_cache (CamelExchangeJournal *exchange_journal, CamelMimeMessage *message,
-		const CamelMessageInfo *mi, gchar **updated_uid, CamelException *ex)
+update_cache (CamelExchangeJournal *exchange_journal,
+              CamelMimeMessage *message,
+              const CamelMessageInfo *mi,
+              gchar **updated_uid,
+              GError **error)
 {
 	CamelOfflineJournal *journal = (CamelOfflineJournal *) exchange_journal;
 	CamelExchangeFolder *exchange_folder = (CamelExchangeFolder *) journal->folder;
@@ -404,26 +412,31 @@ update_cache (CamelExchangeJournal *exchange_journal, CamelMimeMessage *message,
 	gchar *uid;
 
 	if (exchange_folder->cache == NULL) {
-		camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM,
-				     _("Cannot append message in offline mode: cache unavailable"));
+		g_set_error (
+			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
+			_("Cannot append message in offline mode: "
+			  "cache unavailable"));
 		return FALSE;
 	}
 
 	nextuid = camel_folder_summary_next_uid (folder->summary);
 	uid = g_strdup_printf ("-%u", nextuid);
 
-	if (!(cache = camel_data_cache_add (exchange_folder->cache, "cache", uid, ex))) {
+	cache = camel_data_cache_add (
+		exchange_folder->cache, "cache", uid, error);
+	if (cache == NULL) {
 		folder->summary->nextuid--;
 		g_free (uid);
 		return FALSE;
 	}
 
-	if (camel_data_wrapper_write_to_stream ((CamelDataWrapper *) message, cache) == -1
-	    || camel_stream_flush (cache) == -1) {
-		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-				      _("Cannot append message in offline mode: %s"),
-				      g_strerror (errno));
-		camel_data_cache_remove (exchange_folder->cache, "cache", uid, NULL);
+	if (camel_data_wrapper_write_to_stream (
+		(CamelDataWrapper *) message, cache, error) == -1
+	    || camel_stream_flush (cache, error) == -1) {
+		g_prefix_error (
+			error, _("Cannot append message in offline mode: "));
+		camel_data_cache_remove (
+			exchange_folder->cache, "cache", uid, NULL);
 		folder->summary->nextuid--;
 		g_object_unref (cache);
 		g_free (uid);
@@ -432,10 +445,13 @@ update_cache (CamelExchangeJournal *exchange_journal, CamelMimeMessage *message,
 
 	g_object_unref (cache);
 
-	info = camel_folder_summary_info_new_from_message (folder->summary, message, NULL);
+	info = camel_folder_summary_info_new_from_message (
+		folder->summary, message, NULL);
 	info->uid = camel_pstring_strdup (uid);
 
-	exchange_message_info_dup_to ((CamelMessageInfoBase *) info, (CamelMessageInfoBase *) mi);
+	exchange_message_info_dup_to (
+		(CamelMessageInfoBase *) info,
+		(CamelMessageInfoBase *) mi);
 
 	camel_folder_summary_add (folder->summary, info);
 
@@ -447,16 +463,19 @@ update_cache (CamelExchangeJournal *exchange_journal, CamelMimeMessage *message,
 	return TRUE;
 }
 
-void
-camel_exchange_journal_append (CamelExchangeJournal *exchange_journal, CamelMimeMessage *message,
-			       const CamelMessageInfo *mi, gchar **appended_uid, CamelException *ex)
+gboolean
+camel_exchange_journal_append (CamelExchangeJournal *exchange_journal,
+                               CamelMimeMessage *message,
+                               const CamelMessageInfo *mi,
+                               gchar **appended_uid,
+                               GError **error)
 {
 	CamelOfflineJournal *journal = (CamelOfflineJournal *) exchange_journal;
 	CamelExchangeJournalEntry *entry;
 	gchar *uid;
 
-	if (!update_cache (exchange_journal, message, mi, &uid, ex))
-		return;
+	if (!update_cache (exchange_journal, message, mi, &uid, error))
+		return FALSE;
 
 	entry = g_new (CamelExchangeJournalEntry, 1);
 	entry->type = CAMEL_EXCHANGE_JOURNAL_ENTRY_APPEND;
@@ -467,13 +486,14 @@ camel_exchange_journal_append (CamelExchangeJournal *exchange_journal, CamelMime
 	if (appended_uid)
 		*appended_uid = g_strdup (uid);
 
+	return TRUE;
 }
 
 static gint
 find_real_source_for_message (CamelExchangeFolder *folder,
-			      const gchar **folder_name,
-			      const gchar **uid,
-			      gboolean delete_original)
+                              const gchar **folder_name,
+                              const gchar **uid,
+                              gboolean delete_original)
 {
 	CamelOfflineJournal *journal = folder->journal;
 	CamelDListNode *entry, *next;
@@ -510,11 +530,15 @@ find_real_source_for_message (CamelExchangeFolder *folder,
 	return type;
 }
 
-void
-camel_exchange_journal_transfer (CamelExchangeJournal *exchange_journal, CamelExchangeFolder *source_folder,
-				CamelMimeMessage *message, const CamelMessageInfo *mi,
-				const gchar *original_uid, gchar **transferred_uid, gboolean delete_original,
-				CamelException *ex)
+gboolean
+camel_exchange_journal_transfer (CamelExchangeJournal *exchange_journal,
+                                 CamelExchangeFolder *source_folder,
+                                 CamelMimeMessage *message,
+                                 const CamelMessageInfo *mi,
+                                 const gchar *original_uid,
+                                 gchar **transferred_uid,
+                                 gboolean delete_original,
+                                 GError **error)
 {
 	CamelOfflineJournal *journal = (CamelOfflineJournal *) exchange_journal;
 	CamelExchangeJournalEntry *entry;
@@ -522,19 +546,20 @@ camel_exchange_journal_transfer (CamelExchangeJournal *exchange_journal, CamelEx
 	const gchar *real_source_folder = NULL, *real_uid = NULL;
 	gint type;
 
-	if (!update_cache (exchange_journal, message, mi, &uid, ex))
-		return;
+	if (!update_cache (exchange_journal, message, mi, &uid, error))
+		return FALSE;
 
 	real_uid = original_uid;
 	real_source_folder = camel_folder_get_full_name (
 		CAMEL_FOLDER (source_folder));
 
-	type = find_real_source_for_message (source_folder, &real_source_folder,
-					     &real_uid, delete_original);
+	type = find_real_source_for_message (
+		source_folder, &real_source_folder,
+		&real_uid, delete_original);
 
-	if (delete_original) {
-		camel_exchange_folder_remove_message (source_folder, original_uid);
-	}
+	if (delete_original)
+		camel_exchange_folder_remove_message (
+			source_folder, original_uid);
 
 	entry = g_new (CamelExchangeJournalEntry, 1);
 	entry->type = type;
@@ -550,12 +575,16 @@ camel_exchange_journal_transfer (CamelExchangeJournal *exchange_journal, CamelEx
 
 	if (transferred_uid)
 		*transferred_uid = g_strdup (uid);
+
+	return TRUE;
 }
 
-void
+gboolean
 camel_exchange_journal_delete (CamelExchangeJournal *exchange_journal,
-			       const gchar *uid, guint32 flags, guint32 set,
-			       CamelException *ex)
+                               const gchar *uid,
+                               guint32 flags,
+                               guint32 set,
+                               GError **error)
 {
 	CamelOfflineJournal *journal = (CamelOfflineJournal *) exchange_journal;
 	CamelExchangeFolder *exchange_folder = (CamelExchangeFolder *) journal->folder;
@@ -571,5 +600,7 @@ camel_exchange_journal_delete (CamelExchangeJournal *exchange_journal,
 	entry->set = set;
 
 	camel_dlist_addtail (&journal->queue, (CamelDListNode *) entry);
+
+	return TRUE;
 }
 
