@@ -25,19 +25,28 @@
 
 #include <glib.h>
 
-#include <camel/camel-list-utils.h>
-#include <camel/camel-offline-journal.h>
-#include <camel/camel-mime-message.h>
 #include "camel-exchange-folder.h"
 
-G_BEGIN_DECLS
+/* Standard GObject class */
+#define CAMEL_TYPE_EXCHANGE_JOURNAL \
+	(camel_exchange_journal_get_type ())
+#define CAMEL_EXCHANGE_JOURNAL(obj) \
+	(CAMEL_CHECK_CAST \
+	((obj), CAMEL_TYPE_EXCHANGE_JOURNAL, CamelExchangeJournal))
+#define CAMEL_EXCHANGE_JOURNAL_CLASS(cls) \
+	(CAMEL_CHECK_CLASS_CAST \
+	((cls), CAMEL_TYPE_EXCHANGE_JOURNAL, CamelExchangeJournalClass))
+#define CAMEL_IS_EXCHANGE_JOURNAL(obj) \
+	(CAMEL_CHECK_TYPE \
+	((obj), CAMEL_TYPE_EXCHANGE_JOURNAL))
+#define CAMEL_IS_EXCHANGE_JOURNAL_CLASS(cls) \
+	(CAMEL_CHECK_CLASS_TYPE \
+	((cls), CAMEL_TYPE_EXCHANGE_JOURNAL))
+#define CAMEL_EXCHANGE_JOURNAL_GET_CLASS(obj) \
+	(CAMEL_CHECK_GET_CLASS \
+	((obj), CAMEL_TYPE_EXCHANGE_JOURNAL, CamelExchangeJournalClass))
 
-#define CAMEL_TYPE_EXCHANGE_JOURNAL            (camel_exchange_journal_get_type ())
-#define CAMEL_EXCHANGE_JOURNAL(obj)            (CAMEL_CHECK_CAST ((obj), CAMEL_TYPE_EXCHANGE_JOURNAL, CamelExchangeJournal))
-#define CAMEL_EXCHANGE_JOURNAL_CLASS(klass)    (CAMEL_CHECK_CLASS_CAST ((klass), CAMEL_TYPE_EXCHANGE_JOURNAL, CamelExchangeJournalClass))
-#define CAMEL_IS_EXCHANGE_JOURNAL(obj)         (CAMEL_CHECK_TYPE ((obj), CAMEL_TYPE_EXCHANGE_JOURNAL))
-#define CAMEL_IS_EXCHANGE_JOURNAL_CLASS(klass) (CAMEL_CHECK_CLASS_TYPE ((klass), CAMEL_TYPE_EXCHANGE_JOURNAL))
-#define CAMEL_EXCHANGE_JOURNAL_GET_CLASS(obj)  (CAMEL_CHECK_GET_CLASS ((obj), CAMEL_TYPE_EXCHANGE_JOURNAL, CamelExchangeJournalClass))
+G_BEGIN_DECLS
 
 typedef struct _CamelExchangeJournal CamelExchangeJournal;
 typedef struct _CamelExchangeJournalClass CamelExchangeJournalClass;
@@ -65,30 +74,39 @@ struct _CamelExchangeJournalEntry {
 };
 
 struct _CamelExchangeJournal {
-	CamelOfflineJournal parent_object;
-
+	CamelOfflineJournal parent;
 };
 
 struct _CamelExchangeJournalClass {
 	CamelOfflineJournalClass parent_class;
-
 };
 
-CamelType camel_exchange_journal_get_type (void);
+GType camel_exchange_journal_get_type (void);
 
-CamelOfflineJournal *camel_exchange_journal_new (CamelExchangeFolder *folder, const gchar *filename);
+CamelOfflineJournal *
+		camel_exchange_journal_new	(CamelExchangeFolder *folder,
+						 const gchar *filename);
 
 /* interfaces for adding a journal entry */
-void camel_exchange_journal_append (CamelExchangeJournal *journal, CamelMimeMessage *message,
-				    const CamelMessageInfo *mi, gchar **appended_uid, CamelException *ex);
+gboolean	camel_exchange_journal_append	(CamelExchangeJournal *journal,
+						 CamelMimeMessage *message,
+						 const CamelMessageInfo *mi,
+						 gchar **appended_uid,
+						 GError **error);
 
-void camel_exchange_journal_transfer (CamelExchangeJournal *journal, CamelExchangeFolder *source_folder,
-				      CamelMimeMessage *message, const CamelMessageInfo *mi,
-				      const gchar *original_uid, gchar **transferred_uid,
-				      gboolean delete_original, CamelException *ex);
-
-void camel_exchange_journal_delete (CamelExchangeJournal *journal, const gchar *uid,
-				    guint32 flags, guint32 set, CamelException *ex);
+gboolean	camel_exchange_journal_transfer	(CamelExchangeJournal *journal,
+						 CamelExchangeFolder *source_folder,
+						 CamelMimeMessage *message,
+						 const CamelMessageInfo *mi,
+						 const gchar *original_uid,
+						 gchar **transferred_uid,
+						 gboolean delete_original,
+						 GError **error);
+gboolean	camel_exchange_journal_delete	(CamelExchangeJournal *journal,
+						 const gchar *uid,
+						 guint32 flags,
+						 guint32 set,
+						 GError **error);
 
 G_END_DECLS
 
